﻿namespace XF.Domain.Repository.Extensions;
public static class TaskExtensions
{
    /// <summary>
    /// 为 Task<T> 类型的扩展方法，如果实体不为 null，则执行指定的操作。
    /// </summary>
    /// <typeparam name="T">实体的类型</typeparam>
    /// <param name="task">Task 实例</param>
    /// <param name="action">要执行的操作</param>
    /// <returns>Task 返回自身</returns>
    public static async Task Then<T>(this Task<T> task, Action<T> action)
    {
        // 等待任务完成并获取结果
        var result = await task;

        // 如果结果不为 null，则执行传入的操作
        if (result != null)
        {
            action(result);
        }
    }
}
